==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/TextHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TextCellInfoDescriptionMetadata } from "./TextCellInfoDescriptionMetadata";
import { TextHeaderCellInfoDescription } from "./TextHeaderCellInfoDescription";
/**
 * @hidden
 */
var TextHeaderCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TextHeaderCellInfoDescriptionMetadata, _super);
    function TextHeaderCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TextHeaderCellInfoDescriptionMetadata.b = function (a) {
        if (TextHeaderCellInfoDescriptionMetadata.a == null) {
            TextHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TextHeaderCellInfoDescriptionMetadata.c(TextHeaderCellInfoDescriptionMetadata.a);
        }
        if (a.g(TextHeaderCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.s(TextHeaderCellInfoDescriptionMetadata.a);
    };
    TextHeaderCellInfoDescriptionMetadata.c = function (a) {
        TextCellInfoDescriptionMetadata.c(a);
        a.item("IsColumnOptionsEnabled", "Boolean");
        a.item("SortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
        a.item("SortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
        a.item("ColumnOptionsIconAlignment", "ExportedType:string:ColumnOptionsIconAlignment");
        a.item("ColumnOptionsIconAlignment@names", "Unset;None;Opposite");
        a.item("ColumnOptionsIconColor", "Brush");
        a.item("ColumnOptionsIconBehavior", "ExportedType:string:ColumnOptionsIconBehavior");
        a.item("ColumnOptionsIconBehavior@names", "Unset;AlwaysVisible;AppearOnHover;AppearOnHoverAnimate");
    };
    TextHeaderCellInfoDescriptionMetadata.d = function (a) {
        TextHeaderCellInfoDescriptionMetadata.b(a);
        a.u("TextHeaderCellInfo", function () { return new TextHeaderCellInfoDescription(); });
        a.t("TextHeaderCellInfo", TextHeaderCellInfoDescriptionMetadata.a);
    };
    TextHeaderCellInfoDescriptionMetadata.$t = markType(TextHeaderCellInfoDescriptionMetadata, 'TextHeaderCellInfoDescriptionMetadata');
    TextHeaderCellInfoDescriptionMetadata.a = null;
    return TextHeaderCellInfoDescriptionMetadata;
}(Base));
export { TextHeaderCellInfoDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/TextHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TextCellInfoDescriptionMetadata } from "./TextCellInfoDescriptionMetadata";
import { TextHeaderCellInfoDescription } from "./TextHeaderCellInfoDescription";
/**
 * @hidden
 */
var TextHeaderCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TextHeaderCellInfoDescriptionMetadata, _super);
    function TextHeaderCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TextHeaderCellInfoDescriptionMetadata.b = function (a) {
        if (TextHeaderCellInfoDescriptionMetadata.a == null) {
            TextHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TextHeaderCellInfoDescriptionMetadata.c(TextHeaderCellInfoDescriptionMetadata.a);
        }
        if (a.j(TextHeaderCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(TextHeaderCellInfoDescriptionMetadata.a);
    };
    TextHeaderCellInfoDescriptionMetadata.c = function (a) {
        TextCellInfoDescriptionMetadata.c(a);
        a.item("IsColumnOptionsEnabled", "Boolean");
        a.item("SortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
        a.item("SortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
        a.item("ColumnOptionsIconAlignment", "ExportedType:string:ColumnOptionsIconAlignment");
        a.item("ColumnOptionsIconAlignment@names", "Unset;None;Opposite");
        a.item("ColumnOptionsIconColor", "Brush");
        a.item("ColumnOptionsIconBehavior", "ExportedType:string:ColumnOptionsIconBehavior");
        a.item("ColumnOptionsIconBehavior@names", "Unset;AlwaysVisible;AppearOnHover;AppearOnHoverAnimate");
    };
    TextHeaderCellInfoDescriptionMetadata.d = function (a) {
        TextHeaderCellInfoDescriptionMetadata.b(a);
        a.aa("TextHeaderCellInfo", function () { return new TextHeaderCellInfoDescription(); });
        a.z("TextHeaderCellInfo", TextHeaderCellInfoDescriptionMetadata.a);
    };
    TextHeaderCellInfoDescriptionMetadata.$t = markType(TextHeaderCellInfoDescriptionMetadata, 'TextHeaderCellInfoDescriptionMetadata');
    TextHeaderCellInfoDescriptionMetadata.a = null;
    return TextHeaderCellInfoDescriptionMetadata;
}(Base));
export { TextHeaderCellInfoDescriptionMetadata };
